@@ -25,7 +25,7 @@
 #' @seealso [wb_remove_worksheet()]
 #' @examples
 #' ## load existing workbook from package folder
-#' wb <- wb_load(file = system.file("extdata", "loadExample.xlsx", package = "openxlsx2"))
+#' wb <- wb_load(file = system.file("extdata", "openxlsx2_example.xlsx", package = "openxlsx2"))
 #' wb$get_sheet_names() # list worksheets
 #' wb ## view object
 #' ## Add a worksheet
@@ -143,7 +143,7 @@ wb_load <- function(
   )
 
   ## core
-  if (length(appXML)) {
+  if (!data_only && length(appXML)) {
     app_xml <- read_xml(appXML)
     nodes <- xml_node_name(app_xml, "Properties")
     app_list <- lapply(
@@ -151,13 +151,14 @@ wb_load <- function(
       FUN = function(x) xml_node(app_xml, "Properties", x)
     )
     names(app_list) <- nodes
+    wb$app[names(app_list)] <- app_list
   }
 
-  if (length(coreXML) == 1) {
+  if (!data_only && length(coreXML) == 1) {
     wb$core <- read_xml(coreXML, pointer = FALSE)
   }
 
-  if (length(customXML)) {
+  if (!data_only && length(customXML)) {
     wb$append("Content_Types", '<Override PartName="/docProps/custom.xml" ContentType="application/vnd.openxmlformats-officedocument.custom-properties+xml"/>')
     wb$custom <- read_xml(customXML, pointer = FALSE)
   }
@@ -756,7 +757,7 @@ wb_load <- function(
           nms <- unlist(xml_attr(cfs, "conditionalFormatting"))
           cf <- lapply(cfs, function(x) xml_node(x, "conditionalFormatting", "cfRule"))
           names(cf) <- nms
-          conditionalFormatting <- unlist(cf)
+          conditionalFormatting <- un_list(cf)
           wb$worksheets[[i]]$conditionalFormatting <- conditionalFormatting
         }
 
