@@ -10,10 +10,8 @@ library(openxlsx2)
 
 ## -----------------------------------------------------------------------------
 wb <- wb_workbook()
-negStyle <- create_dxfs_style(font_color = wb_colour(hex = "FF9C0006"), bgFill = wb_colour(hex = "FFFFC7CE"))
-posStyle <- create_dxfs_style(font_color = wb_colour(hex = "FF006100"), bgFill = wb_colour(hex = "FFC6EFCE"))
-wb$styles_mgr$add(negStyle, "negStyle")
-wb$styles_mgr$add(posStyle, "posStyle")
+wb$add_dxfs_style(name = "negStyle", font_color = wb_color(hex = "FF9C0006"), bgFill = wb_color(hex = "FFFFC7CE"))
+wb$add_dxfs_style(name = "posStyle", font_color = wb_color(hex = "FF006100"), bgFill = wb_color(hex = "FFC6EFCE"))
 
 ## ----echo=FALSE, warning=FALSE------------------------------------------------
 knitr::include_graphics("img/cf_cells.jpg")
@@ -144,7 +142,7 @@ wb$add_conditional_formatting(
   "containsText",
   cols = 1,
   rows = 1:10,
-  type = "contains",
+  type = "containsText",
   rule = "A"
 )
 wb$add_worksheet("notcontainsText")
@@ -197,14 +195,14 @@ wb$add_conditional_formatting(
 knitr::include_graphics("img/cf_color_scale.jpg")
 
 ## -----------------------------------------------------------------------------
-df <- read_xlsx(system.file("extdata", "readTest.xlsx", package = "openxlsx2"), sheet = 5)
+df <- read_xlsx("https://github.com/JanMarvin/openxlsx-data/raw/main/readTest.xlsx", sheet = 5)
 wb$add_worksheet("colorScale", zoom = 30)
 wb$add_data("colorScale", df, colNames = FALSE) ## write data.frame
 
 ## -----------------------------------------------------------------------------
 wb$add_conditional_formatting(
   "colorScale",
-  cols = seq_along(df),
+  cols = c(1, ncol(df)),
   rows = seq_len(nrow(df)),
   style = c("black", "white"),
   rule = c(0, 255),
@@ -226,7 +224,7 @@ wb <- wb_add_conditional_formatting(
   cols = 1,
   rows = 1:11,
   type = "dataBar"
-) ## Default colours
+) ## Default colors
 
 wb$add_data("databar", -5:5, startCol = 3)
 wb <- wb_add_conditional_formatting(
@@ -239,7 +237,7 @@ wb <- wb_add_conditional_formatting(
     showValue = FALSE,
     gradient = FALSE
   )
-) ## Default colours
+) ## Default colors
 
 wb$add_data("databar", -5:5, startCol = 5)
 wb <- wb_add_conditional_formatting(
