@@ -211,7 +211,7 @@ test_that("wb_add_plot() is a wrapper", {
 
 test_that("wb_add_drawing is a wrapper", {
 
-  fl <- system.file("extdata", "loadExample.xlsx", package = "openxlsx2")
+  fl <- testfile_path("loadExample.xlsx")
   wb <- wb_load(file = fl)
 
   xml <- wb$drawings[[2]]
@@ -488,6 +488,27 @@ test_that("wb_add_cell_style() is a wrapper", {
   )
 })
 
+# wb_add_named_style() ----------------------------------------------------
+
+test_that("wb_add_named_style() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet(1)
+  expect_wrapper(
+    "add_named_style",
+    wb = wb,
+    params = list(name = "Title")
+  )
+})
+
+# wb_add_dxfs_style() -----------------------------------------------------
+
+test_that("wb_add_dxfs_style() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet(1)
+  expect_wrapper(
+    "add_dxfs_style",
+    wb = wb,
+    params = list(name = "dxfs")
+  )
+})
 
 # wb_clone_sheet_style() --------------------------------------------------
 
